<?php

declare(strict_types=1);

namespace Drupal\entity_sync_odata\EntitySync\Api;

// Third-party libraries.
use GuzzleHttp\Client;
use SaintSystems\OData\GuzzleHttpProvider;

/**
 * A Guzzle HTTP provider for the OData client.
 *
 * It extends the default provided by `saintsystems/odata-client-php` simply to
 * support passing default configuration to the Guzzle client. It should be
 * removed after the following pull request is merged into the main repo:
 * https://github.com/saintsystems/odata-client-php/pull/150.
 */
class HttpProvider extends GuzzleHttpProvider {

  /**
   * Constructs a new HttpProvider object.
   *
   * @param array $config
   *   The options to pass to the Guzzle client constructor.
   */
  public function __construct(array $config = []) {
    $this->http = new Client($config);
    $this->timeout = 0;
    $this->extra_options = [];
  }

  /**
   * Configures the default options for the client.
   *
   * @param array $config
   *   The options to set as the defaults on the Guzzle client.
   */
  public function configureDefaults(array $config): void {
    $this->http->configureDefaults($config);
  }

}
