<?php

declare(strict_types=1);

namespace Drupal\entity_sync_odata\EntitySync\Api;

// Third-party libraries.
use KrystalCode\Api\Session\SessionManagerInterface;
use SaintSystems\OData\ODataClient;

/**
 * Provides methods for building OData clients.
 */
trait ODataClientBuilderTrait {

  /**
   * The session manager.
   *
   * @var \KrystalCode\Api\Session\SessionManagerInterface
   */
  protected SessionManagerInterface $sessionManager;

  /**
   * Instantiates and returns the OData client.
   *
   * @param array $client_config
   *   The default options to pass to the Guzzle client.
   * @param array $client_options
   *   The extra options to pass to the Guzzle client.
   *
   * @return \SaintSystems\OData\ODataClient
   *   The client object.
   *
   * @see \Drupal\entity_sync_odata\EntitySync\Api\GuzzleHttpProvider::configureDefaults()
   * @see \Drupal\entity_sync_odata\EntitySync\Api\GuzzleHttpProvider::setExtraOptions()
   */
  protected function getOdataClient(
    array $client_config = [],
    array $client_options = []
  ): ODataClient {
    $token = $this->sessionManager->connect()->getAccessToken();
    $header = $token->getValues()['token_type'] . ' ' . $token->getToken();

    $http_provider = new HttpProvider($client_config);
    $http_provider->setExtraOptions($client_options);

    return new ODataClient(
      $this->sessionManager->getConnection()['url'],
      function ($request) use ($header) {
        $request->headers['Authorization'] = $header;
      },
      $http_provider
    );
  }

}
